@@ -63,7 +63,6 @@ pub struct DPEventLoop {
   // Writers
   add_writer_receiver: TokenReceiverPair<WriterIngredients>,
   remove_writer_receiver: TokenReceiverPair<GUID>,
-  //writer_timed_event_receiver: HashMap<Token, mio_channel::Receiver<TimerMessageType>>,
   stop_poll_receiver: mio_channel::Receiver<()>,
   // GuidPrefix sent in this channel needs to be RTPSMessage source_guid_prefix. Writer needs this
   // to locate RTPSReaderProxy if negative acknack.
@@ -231,6 +230,8 @@ impl DPEventLoop {
           match EntityId::from_token(event.token()) {
             TokenDecode::FixedToken(fixed_token) => match fixed_token {
               STOP_POLL_TOKEN => {
+                let _ = ev_wrapper.stop_poll_receiver.try_recv();
+                // we are not really interested in the content
                 info!("Stopping dp_event_loop");
                 return;
               }
@@ -374,7 +375,7 @@ impl DPEventLoop {
             .poll
             .register(
               &timer,
-              new_reader_ing.guid.entity_id.as_alt_token(),
+              new_reader_ing.alt_entity_token(),
               Ready::readable(),
               PollOpt::edge(),
             )
@@ -433,7 +434,7 @@ impl DPEventLoop {
             .poll
             .register(
               &timer,
-              new_writer_ingredients.guid.entity_id.as_alt_token(),
+              new_writer_ingredients.alt_entity_token(),
               Ready::readable(),
               PollOpt::edge(),
             )
@@ -497,7 +498,7 @@ impl DPEventLoop {
   fn handle_writer_acknack_action(&mut self, _event: &Event) {
     while let Ok((acknack_sender_prefix, acknack_submessage)) = self.ack_nack_receiver.try_recv() {
       let writer_guid = GUID::new_with_prefix_and_id(
-        self.domain_info.domain_participant_guid.guid_prefix,
+        self.domain_info.domain_participant_guid.prefix,
         acknack_submessage.writer_id(),
       );
       if let Some(found_writer) = self.writers.get_mut(&writer_guid.entity_id) {
@@ -518,7 +519,7 @@ impl DPEventLoop {
     info!(
       "update_participant {:?} myself={}",
       participant_guid_prefix,
-      participant_guid_prefix == self.domain_info.domain_participant_guid.guid_prefix
+      participant_guid_prefix == self.domain_info.domain_participant_guid.prefix
     );
 
     {
