@@ -18,10 +18,9 @@ use crate::{
   discovery::{
     content_filter_property::ContentFilterProperty,
     data_types::{
-      spdp_participant_data::{SpdpDiscoveredParticipantData, SpdpDiscoveredParticipantDataKey},
+      spdp_participant_data::SpdpDiscoveredParticipantData,
       topic_data::{
-        DiscoveredReaderData, DiscoveredReaderDataKey, DiscoveredWriterData,
-        DiscoveredWriterDataKey, PublicationBuiltinTopicData, ReaderProxy,
+        DiscoveredReaderData, DiscoveredWriterData, PublicationBuiltinTopicData, ReaderProxy,
         SubscriptionBuiltinTopicData, TopicBuiltinTopicData, WriterProxy,
       },
     },
@@ -128,16 +127,6 @@ impl BuiltinDataDeserializer {
     })
   }
 
-  pub fn generate_spdp_participant_data_key(
-    &self,
-  ) -> Result<SpdpDiscoveredParticipantDataKey, Error> {
-    Ok(SpdpDiscoveredParticipantDataKey(
-      self
-        .participant_guid
-        .ok_or_else(|| log_and_err_discovery!("participant_guid missing"))?,
-    ))
-  }
-
   pub fn generate_reader_proxy(&self) -> Option<ReaderProxy> {
     let remote_reader_guid = if let Some(g) = self.endpoint_guid {
       g
@@ -333,18 +322,6 @@ impl BuiltinDataDeserializer {
     })
   }
 
-  pub fn generate_discovered_reader_data_key(self) -> Result<DiscoveredReaderDataKey, Error> {
-    Ok(DiscoveredReaderDataKey(self.endpoint_guid.ok_or_else(
-      || log_and_err_discovery!("generate_discovered_reader_data_key endpoint_guid missing"),
-    )?))
-  }
-
-  pub fn generate_discovered_writer_data_key(self) -> Result<DiscoveredWriterDataKey, Error> {
-    Ok(DiscoveredWriterDataKey(self.endpoint_guid.ok_or_else(
-      || log_and_err_discovery!("generate_discovered_writer_data_key endpoint_guid missing"),
-    )?))
-  }
-
   pub fn parse_data_little_endian(self, buffer: &[u8]) -> BuiltinDataDeserializer {
     self.parse_data(buffer, RepresentationIdentifier::CDR_LE)
   }
